@@ -1,5 +1,5 @@
 #
-#  Copyright (c) 1997-2000 The Protein Laboratory, University of Copenhagen
+#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
 #  All rights reserved.
 #
 #  Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
 #  Created by Dmitry Karasik <dk@plab.ku.dk>
 #  Modifications by Anton Berezin <tobez@tobez.org>
 #
-#  $Id: DetailedList.pm,v 1.11 2001/09/21 18:39:22 voland Exp $
+#  $Id: DetailedList.pm,v 1.13 2002/05/14 13:22:20 dk Exp $
 
 
 package Prima::DetailedList;
@@ -217,17 +217,6 @@ sub draw_items
 
    # sorting items by index
    $iref = [ sort { $$a[0]<=>$$b[0] } @$iref];
-   # calculating conjoint bars
-   for ( $i = 0; $i < $icount; $i++)
-   {
-      my ( $itemIndex, $x, $y, $x2, $y2, $selected, $focusedItem) = @{$$iref[$i]};
-      if ( defined $lastNormal && ( $y2 + 1 == $lastNormal)) {
-         ${$normals[-1]}[1] = $y;
-      } else {
-         push ( @normals, [ $x, $y, $x2, $y2]);
-      }
-      $lastNormal = $y;
-   }
 
    # calculating conjoint bars for normals / selected
    @normals = ();
