@@ -1,5 +1,5 @@
 #
-#  Copyright (c) 1997-2000 The Protein Laboratory, University of Copenhagen
+#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
 #  All rights reserved.
 #
 #  Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
 #  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 #  SUCH DAMAGE.
 #
-#  $Id: edit.pl,v 1.10 2001/10/25 11:21:10 dk Exp $
+#  $Id: edit.pl,v 1.12 2002/05/14 13:22:26 dk Exp $
 #
 
 =pod 
@@ -40,7 +40,7 @@ Demonstrates use of a standard input line widget
 
 use Prima 'InputLine', Application => { name => 'InputLine sample' };
 
-my $w = Prima::Window-> create( size => [ 700, 300]);
+my $w = Prima::Window-> create( size => [ 700, 300], onDestroy => sub {$::application-> close; });
 
 my $l = $w-> insert( InputLine =>
    text        => '0:::1234 5678 90ab cdef ghij klmn oprq stuv:1::1234 5678 90ab cdef ghij klmn oprq stuv:2::1234 5678 90ab cdef ghij klmn oprq stuv:3::1234 5678 90ab cdef ghij klmn oprq stuv:4::1234 5678 90ab cdef ghij klmn oprq stuv::End',
