@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 1997-2000 The Protein Laboratory, University of Copenhagen
+ * Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,6 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
+ * $Id: codec_prigraph.c,v 1.11 2002/05/14 22:00:48 dk Exp $
  */
 /* Created by Dmitry Karasik <dk@plab.ku.dk> */
 
@@ -374,6 +375,25 @@ load( PImgCodec instance, PImgLoadFileInstance fi)
    CImage( fi-> object)-> create_empty( fi-> object, 
       g-> gbm. w, g-> gbm. h, i-> type); 
 
+   /* free unused palette entries */
+   if ( i-> palSize > 1) {
+      int x = i-> palSize - 1;
+      Color last = ARGB(i->palette[x].r,i->palette[x].g,i->palette[x].b), curr;
+      while (1) {
+         x--;
+         curr = ARGB(i->palette[x].r,i->palette[x].g,i->palette[x].b);
+         if ( curr != last) break;
+         i-> palSize--;
+      }
+      for ( x = 0; x < i-> palSize - 2; x++) {
+         curr = ARGB(i->palette[x].r,i->palette[x].g,i->palette[x].b);
+         if ( curr == last) {
+            i-> palSize--;
+            break;
+         }
+      }
+   }
+
    if (( rc = gbm_read_data( g-> fd, g-> ft, &g-> gbm, PImage( fi-> object)-> data)) != 0) {
       strncpy( fi-> errbuf, gbm_err( rc), 256);
       return false;
@@ -541,7 +561,8 @@ save( PImgCodec instance, PImgSaveFileInstance fi)
          strcat(g-> params, (snprintf(oneOpt, 256, " transcol=%d",(int) pget_i( transparentColorIndex)), oneOpt));
    }
 
-   cm_reverse_palette( i-> palette, pal, 256);
+   memset( pal, 0, sizeof( pal));
+   cm_reverse_palette( i-> palette, pal, i-> palSize);
 
    if (( rc = gbm_write( fi-> fileName, g-> fd, g-> ft, &g-> gbm, ( GBMRGB *) pal, i-> data, g-> statParams)) != 0) {
       strncpy( fi-> errbuf, gbm_err( rc), 256);
