@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 1997-2000 The Protein Laboratory, University of Copenhagen
+ * Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -22,20 +22,22 @@
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
+ * 
+ * $Id: img.c,v 1.17 2002/05/14 13:22:28 dk Exp $
  *
  */
 /* Created by Dmitry Karasik <dk@plab.ku.dk> */
 
-#ifdef __unix
+#include "img.h"
+#include "img_conv.h"
+#include "Icon.h"
+
+#if PRIMA_PLATFORM == apcUnix
 #include <unistd.h>
 #else
 #include <stdlib.h>
 #endif 
 
-#include "img.h"
-#include "img_conv.h"
-#include "Image.h"
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -197,6 +199,7 @@ apc_img_load( Handle self, char * fileName, HV * profile, char * error)
    Bool err = false;
    Bool loadExtras = false, noImageData = false;
    Bool incrementalLoad = false;
+   Bool iconUnmask = false;
    char * baseClassName = "Prima::Image";
 
 
@@ -261,6 +264,9 @@ apc_img_load( Handle self, char * fileName, HV * profile, char * error)
 
    if ( pexist( noImageData) && pget_B( noImageData))
       fi. noImageData = noImageData = true;
+   
+   if ( pexist( iconUnmask) && pget_B( iconUnmask))
+      fi. iconUnmask = iconUnmask = true;
 
    if ( pexist( profiles)) {
       SV * sv = pget_sv( profiles);
@@ -411,6 +417,7 @@ apc_img_load( Handle self, char * fileName, HV * profile, char * error)
 
       fi. loadExtras  = loadExtras;
       fi. noImageData = noImageData;
+      fi. iconUnmask  = iconUnmask;
 
       /* query profile */
       if ( profiles && ( i <= profiles_len)) {
@@ -432,6 +439,8 @@ apc_img_load( Handle self, char * fileName, HV * profile, char * error)
                  fi. loadExtras  = pget_B( loadExtras);
                if ( pexist( noImageData))
                  fi. noImageData = pget_B( noImageData);
+               if ( pexist( iconUnmask))
+                 fi. iconUnmask = pget_B( iconUnmask);
             }   
          }
       }   
@@ -465,6 +474,9 @@ apc_img_load( Handle self, char * fileName, HV * profile, char * error)
       } else
          fi. object = self;
 
+      if ( fi. iconUnmask && kind_of( fi. object, CIcon))
+         PIcon( fi. object)-> autoMasking = amNone;
+
       fi. frameProperties = newHV();
 
       /* loading image */
@@ -577,6 +589,7 @@ apc_img_frame_count( char * fileName)
    fi. frameMap       = &frameMap;
    fi. loadExtras     = true;
    fi. noImageData    = true;
+   fi. iconUnmask     = false;
    fi. extras         = newHV();
    fi. fileProperties = newHV(); 
    fi. frameCount = -1;
@@ -1135,6 +1148,7 @@ apc_img_info2hash( PImgCodec codec)
       }
       hv_store( hv, "loadExtras",  10, newSViv(0),     0);
       hv_store( hv, "noImageData", 11, newSViv(0),     0);
+      hv_store( hv, "iconUnmask",  10, newSViv(0),     0);
       hv_store( hv, "className",    9, newSVpv("Prima::Image", 0), 0);
    } else
       hv = newHV();
