@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 1997-2000 The Protein Laboratory, University of Copenhagen
+ * Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: apc.c,v 1.34 2002/02/06 22:12:41 dk Exp $
+ * $Id: apc.c,v 1.37 2002/05/14 13:22:31 dk Exp $
  */
 /* Created by:
          Dmitry Karasik <dk@plab.ku.dk>
@@ -43,6 +43,7 @@
 #include <fcntl.h>
 #include "os2/os2guts.h"
 #include "Menu.h"
+#include "File.h"
 #include "Window.h"
 #include "Image.h"
 #include "Application.h"
@@ -261,6 +262,46 @@ apc_application_get_widget_from_point( Handle self, Point point)
    return hwnd_to_view( WinWindowFromPoint( HWND_DESKTOP, ( PPOINTL) &point, 1));
 }
 
+static Bool
+process_msg( QMSG * msg)
+{
+   switch( msg-> msg) {
+   case WM_TERMINATE:
+   case WM_QUIT:
+      return false;
+   case WM_SOCKET:
+      {
+         int i;
+         int socket = ( int) msg-> mp2;
+         for ( i = 0; i < guts. files. count; i++) {
+            Handle self = guts. files. items[ i];
+            if (( sys s. file == socket) &&
+                ( PFile( self)-> eventMask & (int) msg-> mp1)) {
+               Event ev;
+               ev. cmd = ((int) msg-> mp1 == feRead) ? cmFileRead :
+                         (( (int) msg-> mp1 == feWrite) ? cmFileWrite : cmFileException);
+               CComponent( self)-> message( self, &ev);
+               break;
+            }
+         }
+         guts. socketPostSync = 0; // clear semaphore
+      }
+      return true;
+   case WM_SOCKET_REHASH:
+      socket_rehash();
+      guts. socketPostSync = 0; // clear semaphore
+      return true;
+   case WM_CROAK:
+      if ( msg-> mp1)
+         croak(( char *) msg-> mp2);
+      else
+         warn(( char *) msg-> mp2);
+      return true;
+
+   }
+   return true;
+}
+
 Bool
 apc_application_go( Handle self)
 {
@@ -268,7 +309,7 @@ apc_application_go( Handle self)
 
    while ( WinGetMsg( guts. anchor, &message, 0, 0, 0))
    {
-      if ( message .msg == WM_TERMINATE) break;
+      if ( !process_msg( &message)) break;
       WinDispatchMsg( guts. anchor, &message);
       kill_zombies();
    }
@@ -310,17 +351,13 @@ apc_application_yield( void)
 
    while ( WinPeekMsg( guts. anchor, &message, 0, 0, 0, PM_REMOVE))
    {
-      switch( message. msg)
-      {
-        case WM_QUIT:
-        case WM_TERMINATE:
-           if ( message. hwnd)
-              WinSendMsg( message. hwnd, WM_CLOSE, MPVOID, MPVOID);
-           break;
-        default:
-           WinDispatchMsg( guts. anchor, &message);
-           kill_zombies();
+      if ( !process_msg( &message)) {
+         if ( message. hwnd)
+            WinSendMsg( message. hwnd, WM_CLOSE, MPVOID, MPVOID);
+         break;
       }
+      WinDispatchMsg( guts. anchor, &message);
+      kill_zombies();
    }
    return true;
 }
@@ -1051,8 +1088,8 @@ Color
 apc_widget_map_color( Handle self, Color color)
 {
    if ((( color & clSysFlag) != 0) && (( color & wcMask) == 0)) color |= var widgetClass;
-   return remap_color( NULLHANDLE, color, true); 
-}   
+   return remap_color( NULLHANDLE, color, true);
+}
 
 #define need_view_recreate    (( DHANDLE( owner) != sys owner)        \
                              || ( syncPaint != is_apt( aptSyncPaint)) \
@@ -1699,7 +1736,7 @@ apc_widget_set_rect( Handle self, int x, int y, int width, int height)
       )
    {
       HWND h = HANDLE;
-      if ( sys s. window. state == wsMinimized) 
+      if ( sys s. window. state == wsMinimized)
          sys s. window. hiddenPos = ( Point){ x, y};
       if ( !WinSetWindowUShort( h, QWS_XRESTORE, x)) apiErr;
       if ( !WinSetWindowUShort( h, QWS_YRESTORE, y)) apiErrRet;
@@ -1729,7 +1766,7 @@ Bool
 apc_widget_set_size_bounds( Handle self, Point min, Point max)
 {
    return true;
-}   
+}
 
 /* XXX */
 Bool
@@ -1888,7 +1925,7 @@ add_item( HWND w, Handle menu, PMenuItemReg i)
        menuItem. afAttribute |= ( i-> checked)  ? MIA_CHECKED        : 0;
        menuItem. afAttribute |= ( i-> disabled) ? MIA_DISABLED       : 0;
        menuItem. id    = i-> id + MENU_ID_AUTOSTART + 1;
-       menuItem. hItem = ( i-> bitmap && PObject( i-> bitmap)-> stage < csDead) ? 
+       menuItem. hItem = ( i-> bitmap && PObject( i-> bitmap)-> stage < csDead) ?
           bitmap_make_handle( i-> bitmap) : 0;
        menuItem. hwndSubMenu = add_item( m, menu, i-> down);
        if (!( i-> divider && i-> rightAdjust))
@@ -2283,82 +2320,3 @@ apc_show_message( const char * message)
 }
 
 // Messages end
-// Help
-static Bool recreateHelp = false;
-
-static Bool
-help_create( void) {
-   HELPINIT h;
-   HWND     hi;
-   int      f;
-   char *   fName = (( PApplication) application)-> helpFile;
-   char     buf[ 512 + 0x6B];
-
-   f = open( fName, O_RDONLY);
-   if ( f == -1) apcErrRet( errApcError);
-   read( f, buf, sizeof( buf));
-   close( f);
-   if ( strncmp( buf, "HSP", 3) != 0) apcErrRet( errApcError);
-   buf[ sizeof( buf) - 1] = 0;
-
-   memset( &h, 0, sizeof( h));
-   h. cb = sizeof( h);
-   (int)h. phtHelpTable = 1;
-   h. pszHelpLibraryName = fName;
-   h. pszHelpWindowTitle = &buf[ 0x6B];
-   hi = WinCreateHelpInstance( guts. anchor, &h);
-   if ( !hi) apiErrRet;
-   guts. helpWnd = hi;
-// if ( !WinAssociateHelpInstance( hi, DHANDLE( application))) apiErr;
-   return true;
-}
-
-static int ctx_hmp2HM[] =
-{
-   hmpMain,          HM_HELP_CONTENTS,
-   hmpContents,      HM_HELP_CONTENTS,
-   hmpExtra,         HM_HELP_INDEX,
-   endCtx
-};
-
-Bool
-apc_help_open_topic( Handle self, long command)
-{
-   int  rc;
-   long hm;
-   MPARAM hm1, hm2;
-   if ( guts. helpWnd == nilHandle || recreateHelp) {
-      if ( recreateHelp) apc_help_close( self);
-      if ( !help_create()) return false;
-   }
-   hm  = ctx_remap_def( command, ctx_hmp2HM, true, HM_DISPLAY_HELP);
-   hm1 = ( hm == HM_DISPLAY_HELP) ? MPFROMLONG( command)        : 0;
-   hm2 = ( hm == HM_DISPLAY_HELP) ? MPFROMSHORT( HM_RESOURCEID) : 0;
-   rc = ( int) WinSendMsg( guts. helpWnd, hm, hm1, hm2);
-   if ( rc != 0) {
-      apiAltErr( rc);
-      return false;
-   }
-   return true;
-}
-
-Bool
-apc_help_close( Handle self)
-{
-   if ( guts. helpWnd) {
-//    WinAssociateHelpInstance( guts. helpWnd, nilHandle);
-      WinDestroyHelpInstance( guts. helpWnd);
-      guts. helpWnd = nilHandle;
-   }
-   recreateHelp  = false;
-   return true;
-}
-
-Bool
-apc_help_set_file( Handle self, const char *helpFile)
-{
-   recreateHelp = true;
-   return true;
-}
-
-// Help end
