@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2000 The Protein Laboratory, University of Copenhagen
+ * Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: gp.c,v 1.16 2002/01/03 14:04:44 dk Exp $
+ * $Id: gp.c,v 1.18 2002/05/14 13:22:31 dk Exp $
  */
 /* Created by Dmitry Karasik <dk@plab.ku.dk> */
 /* apc.c --- apc/ api for os/2 */
@@ -884,6 +884,8 @@ apc_gp_set_fill_pattern( Handle self, FillPattern pattern)
       int i;
       for ( i = 0; i < 8; i++) core[ i] = pattern[ i];
       if ( sys fillBitmap) {
+         GpiSetPatternSet( sys ps, LCID_DEFAULT);
+         GpiDeleteSetId( sys ps, 3);
          GpiDeleteBitmap( sys fillBitmap);
          sys fillBitmap = nilHandle;
       }
@@ -918,13 +920,14 @@ apc_gp_set_font( Handle self, PFont font)
 {
    // very simple & uneffective gpi font management;
    // does not caches fonts, uses only one local ID = 1.
+   USHORT cp = font_enc2cp( font-> encoding);
    FATTRS f = {
       sizeof ( FATTRS),
       0,
       0,                   // does not force match
       "",                  // facename
       0,                   // default registry
-      guts. codePage,      // current code page
+      ( cp == 65535) ? guts. codePage : cp, // the selected or the default codepage
       0,                   // height
       0,                   // width
       0,
